@@ -1,9 +1,9 @@
 import os
+from importlib.resources import path
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 from multimethod import multimethod
-from pandas.core.frame import DataFrame
-from pandas.core.series import Series
+from pandas import DataFrame, Series, read_pickle
 
 from ..caller_base import CallerBase
 from ..error.client_only_endpoint import client_only_endpoint
@@ -23,11 +23,26 @@ from graphdatascience.graph.graph_entity_ops_runner import (
     GraphRelationshipRunner,
     GraphRelationshipsRunner,
 )
+from graphdatascience.graph.graph_type_check import (
+    graph_type_check,
+    graph_type_check_optional,
+)
 
 Strings = Union[str, List[str]]
 
 
 class GraphProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
+    def load_cora(self, graph_name: str = "cora") -> Graph:
+        with path("graphdatascience.resources", "cora_nodes_gzip.pkl") as nodes_resource:
+            nodes = read_pickle(nodes_resource, compression="gzip")
+
+        with path("graphdatascience.resources", "cora_rels_gzip.pkl") as rels_resource:
+            rels = read_pickle(rels_resource, compression="gzip")
+
+        self._namespace = "gds.alpha.graph"
+
+        return self.construct(graph_name, nodes, rels)
+
     @property
     def project(self) -> GraphProjectRunner:
         self._namespace += ".project"
@@ -43,13 +58,14 @@ class GraphProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
         self._namespace += ".sample"
         return GraphSampleRunner(self._query_runner, self._namespace, self._server_version)
 
+    @graph_type_check
     def drop(
         self,
         G: Graph,
         failIfMissing: bool = False,
         dbName: str = "",
         username: Optional[str] = None,
-    ) -> Optional[Series]:
+    ) -> Optional["Series[Any]"]:
         self._namespace += ".drop"
 
         params = {
@@ -69,12 +85,13 @@ class GraphProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
 
         return None
 
-    def exists(self, graph_name: str) -> Series:
+    def exists(self, graph_name: str) -> "Series[Any]":
         self._namespace += ".exists"
         result = self._query_runner.run_query(f"CALL {self._namespace}($graph_name)", {"graph_name": graph_name})
 
         return result.squeeze()  # type: ignore
 
+    @graph_type_check_optional
     def list(self, G: Optional[Graph] = None) -> DataFrame:
         self._namespace += ".list"
 
@@ -96,6 +113,7 @@ class GraphProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
 
         return Graph(graph_name, self._query_runner, self._server_version)
 
+    @graph_type_check
     def _handle_properties(
         self,
         G: Graph,
@@ -230,7 +248,7 @@ class GraphProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
         node_properties: List[str],
         node_labels: Strings = ["*"],
         **config: Any,
-    ) -> Series:
+    ) -> "Series[Any]":
         self._namespace += ".writeNodeProperties"
 
         return self._handle_properties(G, node_properties, node_labels, config).squeeze()  # type: ignore
@@ -241,7 +259,7 @@ class GraphProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
         relationship_type: str,
         relationship_property: str = "",
         **config: Any,
-    ) -> Series:
+    ) -> "Series[Any]":
         self._namespace += ".writeRelationship"
 
         query = f"CALL {self._namespace}($graph_name, $relationship_type, $relationship_property, $config)"
@@ -259,12 +277,13 @@ class GraphProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
         ...
 
     @removeNodeProperties.register
+    @graph_type_check
     def _(
         self,
         G: Graph,
         node_properties: List[str],
         **config: Any,
-    ) -> Series:
+    ) -> Series:  # type: ignore
         self._namespace += ".removeNodeProperties"
 
         query = f"CALL {self._namespace}($graph_name, $properties, $config)"
@@ -278,18 +297,20 @@ class GraphProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
 
     @removeNodeProperties.register
     @compatible_with("removeNodeProperties", max_exclusive=ServerVersion(2, 1, 0))
+    @graph_type_check
     def _(
         self,
         G: Graph,
         node_properties: List[str],
         node_labels: Strings,
         **config: Any,
-    ) -> Series:
+    ) -> Series:  # type: ignore
         self._namespace += ".removeNodeProperties"
 
         return self._handle_properties(G, node_properties, node_labels, config).squeeze()  # type: ignore
 
-    def deleteRelationships(self, G: Graph, relationship_type: str) -> Series:
+    @graph_type_check
+    def deleteRelationships(self, G: Graph, relationship_type: str) -> "Series[Any]":
         self._namespace += ".deleteRelationships"
 
         query = f"CALL {self._namespace}($graph_name, $relationship_type)"
@@ -300,7 +321,9 @@ class GraphProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
 
         return self._query_runner.run_query(query, params).squeeze()  # type: ignore
 
-    def generate(self, graph_name: str, node_count: int, average_degree: int, **config: Any) -> Tuple[Graph, Series]:
+    def generate(
+        self, graph_name: str, node_count: int, average_degree: int, **config: Any
+    ) -> Tuple[Graph, "Series[Any]"]:
         self._namespace += ".generate"
 
         query = f"CALL {self._namespace}($graph_name, $node_count, $average_degree, $config)"
