@@ -1,10 +1,8 @@
-import re
 import warnings
 from typing import Any, Dict, Optional, Tuple, Type, TypeVar, Union
 
 from neo4j import Driver, GraphDatabase
-from pandas import Series
-from pandas.core.frame import DataFrame
+from pandas import DataFrame, Series
 
 from .call_builder import CallBuilder
 from .direct_endpoints import DirectEndpoints
@@ -19,10 +17,6 @@ from .version import __version__
 GDS = TypeVar("GDS", bound="GraphDataScience")
 
 
-class InvalidServerVersionError(Exception):
-    pass
-
-
 class GraphDataScience(DirectEndpoints, UncallableNamespace):
     _AURA_DS_PROTOCOL = "neo4j+s"
 
@@ -31,8 +25,33 @@ class GraphDataScience(DirectEndpoints, UncallableNamespace):
         endpoint: Union[str, Driver, QueryRunner],
         auth: Optional[Tuple[str, str]] = None,
         aura_ds: bool = False,
+        database: Optional[str] = None,
         arrow: bool = True,
+        arrow_disable_server_verification: bool = True,
+        arrow_tls_root_certs: Optional[bytes] = None,
     ):
+        """
+        Parameters
+        ----------
+        endpoint : Union[str, Driver, QueryRunner]
+            The Neo4j endpoint to connect to
+        auth : Optional[Tuple[str, str]], default None
+            A username, password pair for database authentication.
+        aura_ds : bool, default False
+            A flag that indicates that that the client is used to connect
+            to a Neo4j Aura instance.
+        arrow : bool, default True
+            A flag that indicates that the client should use Apache Arrow
+            for data streaming if it is available on the server.
+        arrow_disable_server_verification : bool, default True
+            A flag that indicates that, if the flight client is connecting with
+            TLS, that it skips server verification. If this is enabled, all
+            other TLS settings are overridden.
+        arrow_tls_root_certs : Optional[bytes], default None
+            PEM-encoded certificates that are used for the connecting to the
+            Arrow Flight server.
+        """
+
         if isinstance(endpoint, str):
             self._config: Dict[str, Any] = {"user_agent": f"neo4j-graphdatascience-v{__version__}"}
 
@@ -65,19 +84,30 @@ class GraphDataScience(DirectEndpoints, UncallableNamespace):
             server_version_string = self._query_runner.run_query("RETURN gds.version()").squeeze()
         except Exception as e:
             raise UnableToConnectError(e)
+        finally:
+            # Some Python versions appear to not call __del__ of self._query_runner when an exception
+            # is raised, so we have to close the driver manually.
+            if isinstance(endpoint, str):
+                driver.close()
 
-        server_version_match = re.search(r"^(\d+)\.(\d+)\.(\d+)", server_version_string)
-        if not server_version_match:
-            raise InvalidServerVersionError(f"{server_version_string} is not a valid GDS library version")
-        self._server_version = ServerVersion(*map(int, server_version_match.groups()))
+        self._server_version = ServerVersion.from_string(server_version_string)
         self._query_runner.set_server_version(self._server_version)
 
         if arrow and self._server_version >= ServerVersion(2, 1, 0):
             try:
-                arrow_info: Series = self._query_runner.run_query("CALL gds.debug.arrow()").squeeze()
+                arrow_info: "Series[Any]" = self._query_runner.run_query("CALL gds.debug.arrow()").squeeze()
+                listen_address: str = arrow_info.get(
+                    "advertisedListenAddress", arrow_info["listenAddress"]
+                )  # type: ignore
                 if arrow_info["running"]:
                     self._query_runner = ArrowQueryRunner(
-                        arrow_info["listenAddress"], self._query_runner, auth, driver.encrypted, True
+                        listen_address,
+                        self._query_runner,
+                        self._server_version,
+                        auth,
+                        driver.encrypted,
+                        arrow_disable_server_verification,
+                        arrow_tls_root_certs,
                     )
             except Exception as e:
                 # AuraDS does not have arrow support at this time, so we should not warn about it.
@@ -88,19 +118,30 @@ class GraphDataScience(DirectEndpoints, UncallableNamespace):
                 ):
                     warnings.warn(f"Could not initialize GDS Flight Server client: {e}")
 
+        if database:
+            self._query_runner.set_database(database)
+
         super().__init__(self._query_runner, "gds", self._server_version)
 
     def __getattr__(self, attr: str) -> CallBuilder:
         return CallBuilder(self._query_runner, f"gds.{attr}", self._server_version)
 
-    def set_database(self, db: str) -> None:
-        self._query_runner.set_database(db)
+    def set_database(self, database: str) -> None:
+        self._query_runner.set_database(database)
 
     def database(self) -> Optional[str]:
         return self._query_runner.database()
 
-    def run_cypher(self, query: str, params: Optional[Dict[str, Any]] = None) -> DataFrame:
-        return self._query_runner.run_query(query, params)
+    def run_cypher(
+        self, query: str, params: Optional[Dict[str, Any]] = None, database: Optional[str] = None
+    ) -> DataFrame:
+        qr = self._query_runner
+
+        # The Arrow query runner should not be used to execute arbitary Cypher.
+        if isinstance(self._query_runner, ArrowQueryRunner):
+            qr = self._query_runner.fallback_query_runner()
+
+        return qr.run_query(query, params, database)
 
     def driver_config(self) -> Dict[str, Any]:
         return self._config
