@@ -1,8 +1,9 @@
 from typing import Any
 
-from pandas.core.series import Series
+from pandas import Series
 
 from ..graph.graph_object import Graph
+from ..graph.graph_type_check import graph_type_check
 from .model import Model
 
 
@@ -10,12 +11,14 @@ class NCModel(Model):
     def _query_prefix(self) -> str:
         return "CALL gds.beta.pipeline.nodeClassification.predict."
 
-    def predict_write(self, G: Graph, **config: Any) -> Series:
+    @graph_type_check
+    def predict_write(self, G: Graph, **config: Any) -> "Series[Any]":
         query = f"{self._query_prefix()}write($graph_name, $config)"
         config["modelName"] = self.name()
         params = {"graph_name": G.name(), "config": config}
 
         return self._query_runner.run_query_with_logging(query, params).squeeze()  # type: ignore
 
-    def predict_write_estimate(self, G: Graph, **config: Any) -> Series:
+    @graph_type_check
+    def predict_write_estimate(self, G: Graph, **config: Any) -> "Series[Any]":
         return self._estimate_predict("write", G.name(), config)
