@@ -1,7 +1,6 @@
-from typing import Optional
+from typing import Any, Optional
 
-from pandas.core.frame import DataFrame
-from pandas.core.series import Series
+from pandas import DataFrame, Series
 
 from ..caller_base import CallerBase
 from ..error.client_only_endpoint import client_only_endpoint
@@ -12,6 +11,7 @@ from .lp_training_pipeline import LPTrainingPipeline
 from .nc_pipeline_create_runner import NCPipelineCreateRunner
 from .nc_training_pipeline import NCTrainingPipeline
 from .nr_pipeline_create_runner import NRPipelineCreateRunner
+from .nr_training_pipeline import NRTrainingPipeline
 from .training_pipeline import TrainingPipeline
 
 
@@ -40,7 +40,7 @@ class PipelineProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
 
         return self._query_runner.run_query(query, params)
 
-    def exists(self, pipeline_name: str) -> Series:
+    def exists(self, pipeline_name: str) -> "Series[Any]":
         self._namespace += ".exists"
 
         query = f"CALL {self._namespace}($pipeline_name)"
@@ -48,7 +48,7 @@ class PipelineProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
 
         return self._query_runner.run_query(query, params).squeeze()  # type: ignore
 
-    def drop(self, pipeline: TrainingPipeline) -> Series:
+    def drop(self, pipeline: TrainingPipeline) -> "Series[Any]":
         self._namespace += ".drop"
 
         query = f"CALL {self._namespace}($pipeline_name)"
@@ -73,5 +73,7 @@ class PipelineProcRunner(CallerBase, UncallableNamespace, IllegalAttrChecker):
             return NCTrainingPipeline(pipeline_name, self._query_runner, self._server_version)
         elif pipeline_type == "Link prediction training pipeline":
             return LPTrainingPipeline(pipeline_name, self._query_runner, self._server_version)
+        elif pipeline_type == "Node regression training pipeline":
+            return NRTrainingPipeline(pipeline_name, self._query_runner, self._server_version)
 
         raise ValueError(f"Unknown model type encountered: '{pipeline_type}'")
