@@ -1,19 +1,20 @@
 from abc import ABC, abstractmethod
-from typing import Any, Tuple
+from typing import Any, Dict, Tuple
 
-import pandas
-from pandas.core.frame import DataFrame
-from pandas.core.series import Series
+from pandas import DataFrame, Series
 
 from ..graph.graph_object import Graph
+from ..graph.graph_type_check import graph_type_check
 from ..model.model import Model
 from ..query_runner.query_runner import QueryRunner
+from ..server_version.server_version import ServerVersion
 
 
 class TrainingPipeline(ABC):
-    def __init__(self, name: str, query_runner: QueryRunner):
+    def __init__(self, name: str, query_runner: QueryRunner, server_version: ServerVersion):
         self._name = name
         self._query_runner = query_runner
+        self._server_version = server_version
 
     def name(self) -> str:
         return self._name
@@ -26,7 +27,7 @@ class TrainingPipeline(ABC):
     def _create_trained_model(self, name: str, query_runner: QueryRunner) -> Model:
         pass
 
-    def addNodeProperty(self, procedure_name: str, **config: Any) -> Series:
+    def addNodeProperty(self, procedure_name: str, **config: Any) -> "Series[Any]":
         query = f"{self._query_prefix()}addNodeProperty($pipeline_name, $procedure_name, $config)"
         params = {
             "pipeline_name": self.name(),
@@ -35,18 +36,22 @@ class TrainingPipeline(ABC):
         }
         return self._query_runner.run_query(query, params).squeeze()  # type: ignore
 
-    def addLogisticRegression(self, **config: Any) -> Series:
-        query = f"{self._query_prefix()}addLogisticRegression($pipeline_name, $config)"
-        params = {"pipeline_name": self.name(), "config": config}
-        return self._query_runner.run_query(query, params).squeeze()  # type: ignore
+    @staticmethod
+    def _expand_ranges(config: Dict[str, Any]) -> Dict[str, Any]:
+        def _maybe_expand_tuple(value: Any) -> Any:
+            return {"range": list(value)} if isinstance(value, tuple) else value
 
-    def addRandomForest(self, **config: Any) -> Series:
+        return {key: _maybe_expand_tuple(val) for (key, val) in config.items()}
+
+    def configureAutoTuning(self, **config: Any) -> "Series[Any]":
         query_prefix = self._query_prefix().replace("beta", "alpha")
-        query = f"{query_prefix}addRandomForest($pipeline_name, $config)"
+        query = f"{query_prefix}configureAutoTuning($pipeline_name, $config)"
         params = {"pipeline_name": self.name(), "config": config}
+
         return self._query_runner.run_query(query, params).squeeze()  # type: ignore
 
-    def train(self, G: Graph, **config: Any) -> Tuple[Model, Series]:
+    @graph_type_check
+    def train(self, G: Graph, **config: Any) -> Tuple[Model, "Series[Any]"]:
         query = f"{self._query_prefix()}train($graph_name, $config)"
         config["pipeline"] = self.name()
         params = {
@@ -54,14 +59,15 @@ class TrainingPipeline(ABC):
             "config": config,
         }
 
-        result = self._query_runner.run_query(query, params).squeeze()
+        result = self._query_runner.run_query_with_logging(query, params).squeeze()
 
         return (
             self._create_trained_model(config["modelName"], self._query_runner),
             result,
         )
 
-    def train_estimate(self, G: Graph, **config: Any) -> Series:
+    @graph_type_check
+    def train_estimate(self, G: Graph, **config: Any) -> "Series[Any]":
         query = f"{self._query_prefix()}train.estimate($graph_name, $config)"
         config["pipeline"] = self.name()
         params = {
@@ -71,7 +77,7 @@ class TrainingPipeline(ABC):
 
         return self._query_runner.run_query(query, params).squeeze()  # type: ignore
 
-    def configureSplit(self, **config: Any) -> Series:
+    def configureSplit(self, **config: Any) -> "Series[Any]":
         query = f"{self._query_prefix()}configureSplit($pipeline_name, $config)"
         params = {"pipeline_name": self.name(), "config": config}
 
@@ -79,15 +85,22 @@ class TrainingPipeline(ABC):
 
     def node_property_steps(self) -> DataFrame:
         pipeline_info = self._list_info()["pipelineInfo"][0]
-        return pandas.DataFrame(pipeline_info["featurePipeline"]["nodePropertySteps"])
+        return DataFrame(pipeline_info["featurePipeline"]["nodePropertySteps"])
 
-    def split_config(self) -> Series:
+    def split_config(self) -> "Series[float]":
         pipeline_info = self._list_info()["pipelineInfo"][0]
-        return pandas.Series(pipeline_info["splitConfig"])
+        split_config: "Series[float]" = Series(pipeline_info["splitConfig"])
+        return split_config
 
-    def parameter_space(self) -> Series:
+    def parameter_space(self) -> "Series[Any]":
         pipeline_info = self._list_info()["pipelineInfo"][0]
-        return pandas.Series(pipeline_info["trainingParameterSpace"])
+        parameter_space: "Series[Any]" = Series(pipeline_info["trainingParameterSpace"])
+        return parameter_space
+
+    def auto_tuning_config(self) -> "Series[Any]":
+        pipeline_info = self._list_info()["pipelineInfo"][0]
+        auto_tuning_config: "Series[Any]" = Series(pipeline_info["autoTuningConfig"])
+        return auto_tuning_config
 
     def _list_info(self) -> DataFrame:
         query = "CALL gds.beta.pipeline.list($name)"
@@ -112,8 +125,14 @@ class TrainingPipeline(ABC):
 
         return self._query_runner.run_query(query, params)["exists"].squeeze()  # type: ignore
 
-    def drop(self) -> None:
-        query = "CALL gds.beta.pipeline.drop($pipeline_name)"
-        params = {"pipeline_name": self._name}
+    def drop(self, failIfMissing: bool = False) -> "Series[Any]":
+        query = "CALL gds.beta.pipeline.drop($pipeline_name, $fail_if_missing)"
+        params = {"pipeline_name": self._name, "fail_if_missing": failIfMissing}
 
-        self._query_runner.run_query(query, params)
+        return self._query_runner.run_query(query, params).squeeze()  # type: ignore
+
+    def __str__(self) -> str:
+        return f"{self.__class__.__name__}(name={self.name()}, type={self.type()})"
+
+    def __repr__(self) -> str:
+        return f"{self.__class__.__name__}({self._list_info().to_dict()})"
